@@ -2,12 +2,12 @@ var NAVTREEINDEX0 =
 {
 "annotated.html":[2,0],
 "class_json_rpc_handler_1_1_json_rpc_handler.html":[2,0,0,0],
-"class_json_rpc_handler_1_1_json_rpc_handler.html#a2429030c4345e0549095706aafcc7323":[2,0,0,0,1],
 "class_json_rpc_handler_1_1_json_rpc_handler.html#a3ea126ae78b31c1d3561b62afdaabe13":[2,0,0,0,5],
 "class_json_rpc_handler_1_1_json_rpc_handler.html#a3ea7a37a00ce2099583ad887edb6dd8c":[2,0,0,0,6],
 "class_json_rpc_handler_1_1_json_rpc_handler.html#a43faccf3a3b2445c5fa010168328c942":[2,0,0,0,0],
 "class_json_rpc_handler_1_1_json_rpc_handler.html#a57b8d669a89d1acb16ed75452f0e9250":[2,0,0,0,3],
-"class_json_rpc_handler_1_1_json_rpc_handler.html#ac255a12d9290ce20e13db53ec24f5acc":[2,0,0,0,2],
+"class_json_rpc_handler_1_1_json_rpc_handler.html#a82c991cded9b4c5155be99fac2121cc3":[2,0,0,0,2],
+"class_json_rpc_handler_1_1_json_rpc_handler.html#aabc9ea0be3e207d6a04d780fb3b7fa5f":[2,0,0,0,1],
 "class_json_rpc_handler_1_1_json_rpc_handler.html#af6afae9ef9076e5f4ddc4d002b80ab56":[2,0,0,0,4],
 "classes.html":[2,1],
 "functions.html":[2,2,0],
@@ -15,8 +15,12 @@ var NAVTREEINDEX0 =
 "functions_vars.html":[2,2,2],
 "index.html":[],
 "index.html":[0],
-"index.html#example":[0,1],
-"index.html#intro":[0,0],
+"index.html#jsonrpchandler_1_0":[0,2,2],
+"index.html#jsonrpchandler_1_1":[0,2,1],
+"index.html#jsonrpchandler_1_2":[0,2,0],
+"index.html#jsonrpchandler_relnotes":[0,2],
+"index.html#jsonrpchandlerexample":[0,1],
+"index.html#jsonrpchandlerintro":[0,0],
 "namespace_json_rpc_handler.html":[2,0,0],
 "namespace_json_rpc_handler.html":[1,0,0],
 "namespaces.html":[1,0],
