@@ -1,7 +1,9 @@
 var group__json__functions =
 [
+    [ "make_json", "group__json__functions.html#ga2468410b46f6722168b7d4f6881f9ed2", null ],
     [ "makeFormattedJSONString", "group__json__functions.html#ga8639b5fd6a03f6909431171d7f8b1b31", null ],
     [ "makeJSONString", "group__json__functions.html#gab20a120fadc667cb1b4916b3aa6ae0e1", null ],
+    [ "parse_json", "group__json__functions.html#ga513f9ba32b89d3947da8ee13a68775c1", null ],
     [ "parseJSON", "group__json__functions.html#ga1968f02cbcfa32b940916c073835f1c7", null ],
     [ "parseJSON", "group__json__functions.html#ga47550cb7133bdb218281fc180d61614e", null ]
 ];
\ No newline at end of file
